@@ -10,8 +10,8 @@
 #include <signal.h>
 #include <math.h>
 #ifdef MAEMO2
-  #include <hildon-fm/hildon-widgets/hildon-file-chooser-dialog.h>
-  #include <hildon-widgets/hildon-defines.h>
+  #include <hildon/hildon-file-chooser-dialog.h>
+  #include <hildon/hildon-defines.h>
   #include <gdk/gdkkeysyms.h>
 #endif
 
